﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Core.Layers;
using Infragistics.UltraChart.Shared.Styles;
using Infragistics.UltraChart.Core.Primitives;
using System.Diagnostics;

namespace WindowsFormsApplication5
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            this.ultraChart1.ChartType = Infragistics.UltraChart.Shared.Styles.ChartType.Composite;

            ChartArea myChartArea = new ChartArea();
            this.ultraChart1.CompositeChart.ChartAreas.Add(myChartArea);

            // Defines axes
            AxisItem axisX = new AxisItem();
            axisX.DataType = Infragistics.UltraChart.Shared.Styles.AxisDataType.Numeric;
            axisX.Labels.ItemFormatString = "<DATA_VALUE:0.00>";
            axisX.SetLabelAxisType = SetLabelAxisType.ContinuousData;
            axisX.OrientationType = Infragistics.UltraChart.Shared.Styles.AxisNumber.X_Axis;
            axisX.RangeType = AxisRangeType.Custom;
            axisX.RangeMin = -1;
            axisX.RangeMax = 5;
            myChartArea.Axes.Add(axisX);


            AxisItem axisY = new AxisItem();
            axisY.DataType = Infragistics.UltraChart.Shared.Styles.AxisDataType.Numeric;
            axisY.Labels.ItemFormatString = "<DATA_VALUE:0.00>";
            axisY.Labels.HorizontalAlign = StringAlignment.Far;
            axisY.SetLabelAxisType = SetLabelAxisType.ContinuousData;
            axisY.OrientationType = Infragistics.UltraChart.Shared.Styles.AxisNumber.Y_Axis;
            axisY.RangeType = AxisRangeType.Custom;
            axisY.RangeMin = 0;
            axisY.RangeMax = 220;

            myChartArea.Axes.Add(axisY);


            // Create and add series
            XYSeries BPLseries = new XYSeries();
            BPLseries.Label = "Blood L";
            XYSeries BPHseries = new XYSeries();
            BPHseries.Label = "Blood H";
            XYSeries Pulseseries = new XYSeries();
            Pulseseries.Label = "Pulse";
            DataTable table = createData();

            for (int i = 0; i < table.Rows.Count; i++)
            {
                BPLseries.Points.Add(new XYDataPoint((double)(table.Rows[i][0]), (double)table.Rows[i][1], "", false));
                BPHseries.Points.Add(new XYDataPoint((double)(table.Rows[i][0]), (double)table.Rows[i][2], "", false));
                Pulseseries.Points.Add(new XYDataPoint((double)(table.Rows[i][0]), (double)table.Rows[i][3], "", false));
            }

            // Add a chartLayerAppearance
            ChartLayerAppearance myScatterLayer = new ChartLayerAppearance();
            myScatterLayer.ChartType = Infragistics.UltraChart.Shared.Styles.ChartType.ScatterChart;
            myScatterLayer.ChartArea = myChartArea;
            myScatterLayer.AxisX = axisX;
            myScatterLayer.AxisY = axisY;
            myScatterLayer.Series.Add(BPLseries);
            myScatterLayer.Series.Add(BPHseries);
            myScatterLayer.Series.Add(Pulseseries);


            ScatterChartAppearance sca1 = new ScatterChartAppearance();
            sca1.ConnectWithLines = true;
            sca1.Icon = SymbolIcon.None;
            myScatterLayer.ChartTypeAppearance = sca1;



            this.ultraChart1.Series.Add(BPLseries);
            this.ultraChart1.Series.Add(BPHseries);
            this.ultraChart1.Series.Add(Pulseseries);
            this.ultraChart1.CompositeChart.ChartLayers.Add(myScatterLayer);


            CompositeLegend myLegend = new CompositeLegend();
            myLegend.ChartLayers.Add(myScatterLayer);
            myLegend.Bounds = new Rectangle(88, 2, 11, 15);
            myLegend.BoundsMeasureType = MeasureType.Percentage;
            myLegend.PE.ElementType = PaintElementType.Gradient;
            myLegend.PE.FillGradientStyle = GradientStyle.ForwardDiagonal;
            myLegend.PE.Fill = Color.CornflowerBlue;
            myLegend.PE.FillStopColor = Color.Transparent;
            myLegend.Border.CornerRadius = 10;
            myLegend.Border.Thickness = 1;

            this.ultraChart1.CompositeChart.Legends.Add(myLegend);
        }


        private static DataTable createData()
        {
            DataTable dt = new DataTable();
            dt.Columns.Add("Time", typeof(double));
            dt.Columns.Add("BPL", typeof(double));
            dt.Columns.Add("BPH", typeof(double));
            dt.Columns.Add("Pulse", typeof(double));

            dt.Rows.Add(0.0, 0, 0, 0);
            dt.Rows.Add(0.2, 90, 140, 80);
            dt.Rows.Add(0.3, 110, 160, 90);
            dt.Rows.Add(0.7, 115, 160, 80);
            dt.Rows.Add(1, 120, 155, 90);
            dt.Rows.Add(1.2, 122, 157, 90);
            dt.Rows.Add(1.5, 120, 160, 80);
            dt.Rows.Add(3, 150, 200, 90);
            dt.Rows.Add(4, 100, 120, 70);

            return dt;

        }

        private void ultraChart1_FillSceneGraph(object sender, Infragistics.UltraChart.Shared.Events.FillSceneGraphEventArgs e)
        {
            foreach (Primitive pr in e.SceneGraph)
            {
                if (pr.GetType() == typeof(Text) && ((Text)pr).labelStyle != null && ((Text)pr).labelStyle.HorizontalAlign == StringAlignment.Far)
                {
                    string ss = ((Text)pr).GetTextString();
                    if (ss.Length >= 5)
                    {
                        ss = ss.Remove(3);
                        ((Text)pr).PE.Fill = Color.Red;
                        ((Text)pr).SetTextString(ss);
                    }
                }
            }
        }
    }
}
